ensure_caliband

Function ensure_caliband 

pub async fn ensure_caliband(
    workspace_root: &Path,
    env: &DiscoveryEnv,
    cfg: &EnsureConfig,
) -> Result<CalibandClient>
Ensure a caliband daemon is reachable for workspace_root, returning a client bound to its control socket. If none is reachable and autostart is set, spawns the daemon and waits for the socket.